pub enum DebugInfoMergeError<Exec: Idx, Src: Idx> {
InvalidOptionField {
forest_index: usize,
context: &'static str,
err: InvalidOptionalIndexError,
},
SourceMapWithoutGraph {
forest_index: usize,
},
MissingExecNodeMapping {
forest_index: usize,
exec_node: Exec,
},
MissingSourceNodeMapping {
forest_index: usize,
source_node: Src,
},
MissingTypeStringMapping {
forest_index: usize,
string_idx: DebugStringIdx,
},
MissingTypeMapping {
forest_index: usize,
type_idx: DebugTypeIdx,
},
MissingSourceStringMapping {
forest_index: usize,
string_idx: DebugStringIdx,
},
MissingSourceFileMapping {
forest_index: usize,
file_idx: DebugFileIdx,
},
MissingSourceLocationMapping {
forest_index: usize,
location_idx: DebugLocIdx,
},
MissingFunctionStringMapping {
forest_index: usize,
string_idx: DebugStringIdx,
},
MissingFunctionMapping {
forest_index: usize,
function_idx: DebugFunctionIdx,
},
}Expand description
Error returned when package-owned source/debug metadata cannot be remapped after a
miden_core::mast::MastForest merge.
Variants
InvalidOptionField
A stable-layout optional field has an invalid discriminant.
SourceMapWithoutGraph
The package has source-keyed metadata rows without a source graph to define source IDs.
MissingExecNodeMapping
A source/debug occurrence points at an execution node that was not present in the merge map.
MissingSourceNodeMapping
A source-keyed metadata row refers to a source/debug occurrence that was not present in the corresponding source graph.
MissingTypeStringMapping
A debug type row refers to a string index that is not present in its type string table.
MissingTypeMapping
A debug type or function row refers to a type index that is not present in its type table.
MissingSourceStringMapping
A debug source-file row refers to a string index that is not present in its source string table.
MissingSourceFileMapping
A debug function or inline-call row refers to a source-file index that is not present in its source-file table.
MissingSourceLocationMapping
MissingFunctionStringMapping
A debug function row refers to a string index that is not present in its function string table.
MissingFunctionMapping
A debug inline-call row refers to a function index that is not present in its function table.