pub enum DebugTypeInfo {
Primitive(DebugPrimitiveType),
Pointer {
pointee_type_idx: DebugTypeIdx,
},
Array {
element_type_idx: DebugTypeIdx,
count: Option<u32>,
},
Struct {
name_idx: DebugStringIdx,
size: u32,
fields: Vec<DebugFieldInfo>,
},
Function {
return_type_idx: Option<DebugTypeIdx>,
param_type_indices: Vec<DebugTypeIdx>,
},
Enum {
name_idx: DebugStringIdx,
size: u32,
discriminant_type_idx: DebugTypeIdx,
variants: Vec<DebugVariantInfo>,
},
Variadic,
Unknown,
}Expand description
Type information for debug purposes.
This encodes the type of a variable or expression, enabling debuggers to properly display values on the stack or in memory.
Variants
Primitive(DebugPrimitiveType)
A primitive type (e.g., i32, i64, felt, etc.)
Pointer
A pointer type pointing to another type
Fields
pointee_type_idx: DebugTypeIdxThe type being pointed to (index into type table)
Array
An array type
Fields
element_type_idx: DebugTypeIdxThe element type (index into type table)
Struct
A struct type
Fields
name_idx: DebugStringIdxName of the struct (index into string table)
fields: Vec<DebugFieldInfo>Fields of the struct
Function
A function type
Fields
return_type_idx: Option<DebugTypeIdx>Return type (index into type table, None for void)
param_type_indices: Vec<DebugTypeIdx>Parameter types (indices into type table)
Enum
An enum type.
Fields
name_idx: DebugStringIdxName of the enum (index into string table).
discriminant_type_idx: DebugTypeIdxType of the enum discriminant.
variants: Vec<DebugVariantInfo>Variants of the enum.
Variadic
Represents a variable number (zero or more) of types in function argument or result position
Variadic type parameters are always in trailing position, but may be preceded by non-variadic type parameters
Unknown
An unknown or opaque type
Implementations
Sourceimpl DebugTypeInfo
impl DebugTypeInfo
Sourcepub fn recover_registered_type<Exec: Idx, Src: Idx>(
&self,
debug_info: &DebugInfo<Exec, Src>,
cached_types: &mut HashMap<DebugTypeIdx, (Type, Option<Arc<TypeExpr>>), FxBuildHasher>,
) -> Option<(Type, Option<Arc<TypeExpr>>)>
pub fn recover_registered_type<Exec: Idx, Src: Idx>( &self, debug_info: &DebugInfo<Exec, Src>, cached_types: &mut HashMap<DebugTypeIdx, (Type, Option<Arc<TypeExpr>>), FxBuildHasher>, ) -> Option<(Type, Option<Arc<TypeExpr>>)>
Recovers the structural and source-level types represented by this debug type.
Returns None when the debug type contains an invalid reference, cannot be represented by
the assembly type system, or participates in a reference cycle.