pub struct DebugErrorMessage {
pub err_code: u64,
pub message: DebugStringIdx,
/* private fields */
}Expand description
Assertion error message keyed by its runtime error code.
Fields
err_code: u64Runtime error code emitted by the assembled assertion operation.
message: DebugStringIdxString table index of the error message content
Implementations
Sourceimpl DebugErrorMessage
impl DebugErrorMessage
pub fn new(err_code: u64, message: DebugStringIdx) -> Self