pub struct DebugSourcesSection {
pub version: u8,
pub strings: Vec<Arc<str>>,
pub files: Vec<DebugFileInfo>,
}Expand description
Debug sources section containing source file paths and checksums.
This section stores deduplicated source file information that is referenced by the debug functions section.
String indices in sub-types (e.g., path_idx in DebugFileInfo) are relative
to this section’s own string table.
Fields
version: u8Version of the debug sources format
strings: Vec<Arc<str>>String table containing file paths
files: Vec<DebugFileInfo>Source file table
Implementations
Sourceimpl DebugSourcesSection
impl DebugSourcesSection
Sourcepub fn add_string(&mut self, s: Arc<str>) -> u32
pub fn add_string(&mut self, s: Arc<str>) -> u32
Adds a string to the string table and returns its index.
Sourcepub fn add_file(&mut self, file: DebugFileInfo) -> u32
pub fn add_file(&mut self, file: DebugFileInfo) -> u32
Adds a file to the file table and returns its index.
Sourcepub fn get_file(&self, idx: u32) -> Option<&DebugFileInfo>
pub fn get_file(&self, idx: u32) -> Option<&DebugFileInfo>
Gets a file by index.