pub struct DebugTypesSection {
pub version: u8,
pub strings: Vec<Arc<str>>,
pub types: Vec<DebugTypeInfo>,
}Expand description
Debug types section containing type definitions for a MASP package.
This section stores type information (primitives, structs, arrays, pointers, function types) that enables debuggers to properly display values.
String indices in sub-types (e.g., name_idx in DebugFieldInfo) are relative
to this section’s own string table.
Fields
version: u8Version of the debug types format
strings: Vec<Arc<str>>String table containing type names, field names
types: Vec<DebugTypeInfo>Type table containing all type definitions
Implementations
Sourceimpl DebugTypesSection
impl DebugTypesSection
Sourcepub fn add_string(&mut self, s: Arc<str>) -> u32
pub fn add_string(&mut self, s: Arc<str>) -> u32
Adds a string to the string table and returns its index.
Sourcepub fn add_type(&mut self, ty: DebugTypeInfo) -> DebugTypeIdx
pub fn add_type(&mut self, ty: DebugTypeInfo) -> DebugTypeIdx
Adds a type to the type table and returns its index.
Sourcepub fn get_type(&self, idx: DebugTypeIdx) -> Option<&DebugTypeInfo>
pub fn get_type(&self, idx: DebugTypeIdx) -> Option<&DebugTypeInfo>
Gets a type by index.