#[repr(C)]pub struct FunctionInfo<N: Idx> {
pub mast_root: Word,
pub source_node: OptionalIndex<N>,
pub type_idx: OptionalIndex<DebugTypeIdx>,
pub linkage_name_idx: OptionalIndex<DebugStringIdx>,
pub name_idx: DebugStringIdx,
pub file_idx: DebugFileIdx,
pub line: LineIndex,
pub column: ColumnIndex,
}Fields
mast_root: WordMAST root digest of this function.
This links the debug info to the compiled code if source_node is unknown
source_node: OptionalIndex<N>The source occurrance this function is linked to, if known
type_idx: OptionalIndex<DebugTypeIdx>Type signature of this function (index into type table, optional)
linkage_name_idx: OptionalIndex<DebugStringIdx>Assembler/linker-visible name (index into string table, optional).
Set when the name known to the linker differs from the name as written in the source code (which is tracked by name_idx).
name_idx: DebugStringIdxName of the function (index into string table).
When linkage_name_idx is unset, this is also the assembler/linker-visible name.
file_idx: DebugFileIdxFile containing this function (index into file table)
line: LineIndexLine index where the function starts (0-indexed)
column: ColumnIndexColumn index where the function starts (0-indexed)
Implementations
Sourceimpl<N: Idx> FunctionInfo<N>
impl<N: Idx> FunctionInfo<N>
Sourcepub fn new(
source_node: Option<N>,
name_idx: DebugStringIdx,
file_idx: DebugFileIdx,
line: LineNumber,
column: ColumnNumber,
mast_root: Word,
) -> Self
pub fn new( source_node: Option<N>, name_idx: DebugStringIdx, file_idx: DebugFileIdx, line: LineNumber, column: ColumnNumber, mast_root: Word, ) -> Self
Creates a new function info.
Sourcepub fn with_linkage_name(self, linkage_name_idx: DebugStringIdx) -> Self
pub fn with_linkage_name(self, linkage_name_idx: DebugStringIdx) -> Self
Sets the linkage name.
Sourcepub fn with_type(self, type_idx: DebugTypeIdx) -> Self
pub fn with_type(self, type_idx: DebugTypeIdx) -> Self
Sets the type index.