#[non_exhaustive]#[repr(u8)]pub enum PackageKind {
Library = 0,
Executable = 1,
AccountComponent = 2,
NoteScript = 3,
TransactionScript = 4,
}Expand description
The kind of project that produced this package.
This helps consumers of the package understand how to use it (e.g., as an account component, a note script, a transaction script, etc.).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Library = 0
A generic code library package.
Executable = 1
An executable program package.
AccountComponent = 2
An account component package.
NoteScript = 3
A note script package.
TransactionScript = 4
A transaction script package.
Implementations