pub struct Dependency {
pub name: DependencyName,
pub digest: Word,
}Expand description
A package dependency
Fields
name: DependencyNameThe name of the dependency. Serves as a human-readable identifier for the dependency and a search hint for the resolver
digest: WordThe digest of the dependency. Serves as an ultimate source of truth for identifying the dependency.