Structs
- Constant
Export - A constant definition exported by a package
- Dependency
- A package dependency
- Dependency
Name - The name of a dependency
- Invalid
Package Kind Error - Error returned when trying to convert an invalid u8 to a PackageKind.
- Library
- Represents a library where all modules were compiled into a
MastForest. - Mast
Forest - Represents one or more procedures, represented as a collection of
MastNodes. - MemDependency
Resolver ByDigest - Package
- A package containing a Program/Library, and a manifest (exports and dependencies).
- Package
Manifest - The manifest of a package, containing the set of package dependencies (libraries or packages) and exported items (procedures, constants, types), if known.
- PathBuf
- Path to an item in a library, i.e. module, procedure, constant or type.
- Procedure
Export - A procedure exported by a package, along with its digest, signature, and attributes.
- Procedure
Name - Procedure name.
- Program
- An executable program for Miden VM.
- Qualified
Procedure Name - Represents a qualified procedure name, e.g.
std::math::u64::add, parsed into it’s constituent Path and ProcedureName components. - Section
- Section
Id - A unique identifier for optional sections of the Miden package format
- Type
Export - A named type declaration exported by a package
- Version
- SemVer version as defined by https://semver.org.
- Version
Error - Error parsing a SemVer version or version requirement.
- Word
- A unit of data consisting of 4 field elements.
Enums
- Invalid
Section IdError - Local
Resolved Dependency - Resolved local(loaded) dependency
- Mast
Artifact - The artifact produced by lowering a program or library to a Merkelized Abstract Syntax Tree
- Package
Export - Represents a named item exported from a package.
- Package
Kind - The kind of project that produced this package.
- Resolved
Dependency - Resolved dependency In the future, we intend to add Registry variant to describe dependencies to be loaded from the registry.