#[repr(u8)]pub enum DebugPrimitiveType {
Show 17 variants
Void = 0,
Bool = 1,
I8 = 2,
U8 = 3,
I16 = 4,
U16 = 5,
I32 = 6,
U32 = 7,
I64 = 8,
U64 = 9,
I128 = 10,
U128 = 11,
F32 = 12,
F64 = 13,
Felt = 14,
Word = 15,
U256 = 16,
}Expand description
Primitive type variants supported by the debug info format.
New variants must be added at the end to maintain backwards compatibility with previously serialized debug info.
Variants
Void = 0
Void type (0 bytes)
Bool = 1
Boolean (1 byte)
I8 = 2
Signed 8-bit integer
U8 = 3
Unsigned 8-bit integer
I16 = 4
Signed 16-bit integer
U16 = 5
Unsigned 16-bit integer
I32 = 6
Signed 32-bit integer
U32 = 7
Unsigned 32-bit integer
I64 = 8
Signed 64-bit integer
U64 = 9
Unsigned 64-bit integer
I128 = 10
Signed 128-bit integer
U128 = 11
Unsigned 128-bit integer
F32 = 12
32-bit floating point
F64 = 13
64-bit floating point
Felt = 14
Miden field element (64-bit, but with field semantics)
Word = 15
Miden word (4 field elements)
U256 = 16
Unsigned 256-bit integer
Implementations
Sourceimpl DebugPrimitiveType
impl DebugPrimitiveType
Sourcepub fn from_discriminant(discriminant: u8) -> Option<Self>
pub fn from_discriminant(discriminant: u8) -> Option<Self>
Converts a discriminant byte to a primitive type.