pub type DebugFunctionInfo = FunctionInfo<DebugSourceNodeId>;Expand description
Debug information for a function.
Links source-level function information to the compiled MAST representation.
Aliased Type
#[repr(C)]pub struct DebugFunctionInfo {
pub mast_root: Word,
pub source_node: OptionalIndex<DebugSourceNodeId>,
pub type_idx: OptionalIndex<DebugTypeIdx>,
pub linkage_name_idx: OptionalIndex<DebugStringIdx>,
pub name_idx: DebugStringIdx,
pub file_idx: DebugFileIdx,
pub line: LineIndex,
pub column: ColumnIndex,
}Fields
mast_root: WordMAST root digest of this function.
This links the debug info to the compiled code if source_node is unknown
source_node: OptionalIndex<DebugSourceNodeId>The source occurrance this function is linked to, if known
type_idx: OptionalIndex<DebugTypeIdx>Type signature of this function (index into type table, optional)
linkage_name_idx: OptionalIndex<DebugStringIdx>Assembler/linker-visible name (index into string table, optional).
Set when the name known to the linker differs from the name as written in the source code (which is tracked by name_idx).
name_idx: DebugStringIdxName of the function (index into string table).
When linkage_name_idx is unset, this is also the assembler/linker-visible name.
file_idx: DebugFileIdxFile containing this function (index into file table)
line: LineIndexLine index where the function starts (0-indexed)
column: ColumnIndexColumn index where the function starts (0-indexed)